<?php
namespace Pinpoint\LogoManager\Controller\Adminhtml\Logo;

use Magento\Backend\App\Action;
use Pinpoint\LogoManager\Model\Page;
use Magento\Framework\App\Request\DataPersistorInterface;
use Magento\Framework\Exception\LocalizedException;

/**
 * Class Save
 * @package Pinpoint\LogoManager\Controller\Adminhtml\Logo
 */
class Save extends \Magento\Backend\App\Action
{
    /**
     * Authorization level of a basic admin session
     *
     * @see _isAllowed()
     */
    const ADMIN_RESOURCE = 'Pinpoint_LogoManager::addedit';

    /**
     * @var DataPersistorInterface
     */
    protected $dataPersistor;

    /**
     * @var \Pinpoint\LogoManager\Model\Logo
     */
    protected $logo;

    /**
     * @param Action\Context $context
     * @param DataPersistorInterface $dataPersistor
     */
    public function __construct(
        Action\Context $context,
        DataPersistorInterface $dataPersistor,
        \Pinpoint\LogoManager\Model\Logo $logo
    ) {
        $this->dataPersistor = $dataPersistor;
        $this->logo = $logo;

        parent::__construct($context);
    }

    /**
     * Save action
     *
     * @SuppressWarnings(PHPMD.CyclomaticComplexity)
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        $data = $this->getRequest()->getPostValue();
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        if ($data) {
            if (isset($data['is_active']) && $data['is_active'] === 'true') {
                $data['is_active'] = \Pinpoint\LogoManager\Model\Logo::STATUS_ENABLED;
            }
            if (empty($data['id'])) {
                $data['id'] = null;
            }

            /** @var \Pinpoint\LogoManager\Model\Logo $model */
            $model = $this->logo;

            $id = $this->getRequest()->getParam('id');
            if ($id) {
                $model->load($id);
            }

            $data['logo'] = $data['logo'][0]['file'];

            $model->setData($data);

            try {
                $model->save();
                $this->messageManager->addSuccess(__('The logo has been saved.'));
                $this->dataPersistor->clear('pinpoint_logomanager_logo');
                if ($this->getRequest()->getParam('back')) {
                    return $resultRedirect->setPath('*/*/edit', ['id' => $model->getId(), '_current' => true]);
                }
                return $resultRedirect->setPath('*/*/list');
            } catch (LocalizedException $e) {
                $this->messageManager->addError($e->getMessage());
            } catch (\Exception $e) {
                $this->messageManager->addException($e, __('Something went wrong while saving the Logo.'));
            }

            $this->dataPersistor->set('pinpoint_logomanager_logo', $data);
            return $resultRedirect->setPath('*/*/edit', ['id' => $this->getRequest()->getParam('id')]);
        }
        return $resultRedirect->setPath('*/*/list');
    }    
}
